@@ -3,7 +3,7 @@ package POE::Component::IRC::Plugin::BasePoCoWrap;
 use warnings;
 use strict;
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 use Carp;
 use POE;
@@ -493,7 +493,7 @@ functionality this base class offers. B<Make sure to proof read> ;)
             $irc->yield( register => 'all' );
             
             $irc->plugin_add(
-                'XKCD' =>
+                'EXAMPLE' =>
                     POE::Component::IRC::Plugin::EXAMPLE->new
             );
 
@@ -532,6 +532,7 @@ functionality this base class offers. B<Make sure to proof read> ;)
                     response_event   => 'irc_EXAMPLE',
                     banned           => [ qr/aol\.com$/i ],
                     addressed        => 1,
+                    root             => [ qr/mah.net$/i ],
                     trigger          => qr/^EXAMPLE\s+(?=\S)/i,
                     listen_for_input => [ qw(public notice privmsg) ],
                     eat              => 1,
@@ -575,6 +576,17 @@ functionality this base class offers. B<Make sure to proof read> ;)
     the regexes listed in the C<banned> arrayref, plugin will ignore the
     request. B<Defaults to:> C<[]> (no bans are set).
 
+    =head3 root
+
+        ->new( root => [ qr/\Qjust.me.and.my.friend.net\E$/i ] );
+
+    B<Optional>. As opposed to C<banned> argument, the C<root> argument
+    B<allows> access only to people whose usermasks match B<any> of
+    the regexen you specify in the arrayref the argument takes as a value.
+    B<By default:> it is not specified. B<Note:> as opposed to C<banned>
+    specifying an empty arrayref to C<root> argument will restrict
+    access to everyone.
+
     =head3 trigger
 
         ->new( trigger => qr/^EXAMPLE\s+(?=\S)/i );
@@ -647,8 +659,8 @@ functionality this base class offers. B<Make sure to proof read> ;)
 
     The event handler set up to handle the event, name of which you've
     specified in the C<response_event> argument to the constructor
-    (it defaults to C<irc_xkcd>) will recieve input
-    every time comic request is completed. The input will come in EXAMPLE.
+    (it defaults to C<irc_EXAMPLE>) will recieve input
+    every time request is completed. The input will come in EXAMPLE.
     The EXAMPLE as follows:
 
     EXAMPLE
